<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS language="pt" version="2.1">
<context>
    <name>AboutDlg</name>
    <message>
        <source>About</source>
        <translation>Acerca</translation>
    </message>
</context>
<context>
    <name>AddNewTorrentDialog</name>
    <message>
        <source>Category:</source>
        <translation>Categoria:</translation>
    </message>
    <message>
        <source>Start torrent</source>
        <translation>Iniciar torrent</translation>
    </message>
    <message>
        <source>Skip hash check</source>
        <translation>Ignorar verificação hash</translation>
    </message>
    <message>
        <source>Create subfolder</source>
        <translation>Criar sub-pasta</translation>
    </message>
    <message>
        <source>Torrent Management Mode:</source>
        <translation>Modo de gestão de torrent:</translation>
    </message>
</context>
<context>
    <name>CategoryFilterModel</name>
    <message>
        <source>All</source>
        <translation>Tudo</translation>
    </message>
    <message>
        <source>Uncategorized</source>
        <translation>Sem categoria</translation>
    </message>
</context>
<context>
    <name>CategoryFilterWidget</name>
    <message>
        <source>Add category...</source>
        <translation>Adicionar categoria</translation>
    </message>
    <message>
        <source>Remove category</source>
        <translation>Remover categoria</translation>
    </message>
    <message>
        <source>Remove unused categories</source>
        <translation>Remover categorias não utilizadas</translation>
    </message>
    <message>
        <source>Resume torrents</source>
        <translation>Retomar torrents</translation>
    </message>
    <message>
        <source>Pause torrents</source>
        <translation>Pausar torrents</translation>
    </message>
    <message>
        <source>Delete torrents</source>
        <translation>Eliminar torrents</translation>
    </message>
    <message>
        <source>New Category</source>
        <translation>Nova categoria</translation>
    </message>
    <message>
        <source>Edit category...</source>
        <translation>Editar categoria...</translation>
    </message>
</context>
<context>
    <name>HttpServer</name>
    <message>
        <source>Exit qBittorrent</source>
        <translation>Sair do qBittorrent</translation>
    </message>
    <message>
        <source>Only one link per line</source>
        <translation>Apenas uma ligação por linha</translation>
    </message>
    <message>
        <source>Global upload rate limit must be greater than 0 or disabled.</source>
        <translation>O limite do rácio global para uploads tem que ser superior a 0 ou estar inativo.</translation>
    </message>
    <message>
        <source>Global download rate limit must be greater than 0 or disabled.</source>
        <translation>O limite do rácio global para downloads tem que ser superior a 0 ou estar inativo.</translation>
    </message>
    <message>
        <source>Alternative upload rate limit must be greater than 0 or disabled.</source>
        <translation>O limite do rácio alternativo para uploads tem que ser superior a 0 ou estar inativo.</translation>
    </message>
    <message>
        <source>Alternative download rate limit must be greater than 0 or disabled.</source>
        <translation>O limite do rácio alternativo para downloads tem que ser superior a 0 ou estar inativo.</translation>
    </message>
    <message>
        <source>Maximum active downloads must be greater than -1.</source>
        <translation>O número máximo de downloads ativos tem que ser superior a -1.</translation>
    </message>
    <message>
        <source>Maximum active uploads must be greater than -1.</source>
        <translation>O número máximo de uploads ativos tem que ser superior a -1.</translation>
    </message>
    <message>
        <source>Maximum active torrents must be greater than -1.</source>
        <translation>O número máximo de torrents ativos tem que ser superior a -1.</translation>
    </message>
    <message>
        <source>Maximum number of connections limit must be greater than 0 or disabled.</source>
        <translation>O número máximo do limite de ligações tem que ser superior a 0 ou estar inativo.</translation>
    </message>
    <message>
        <source>Maximum number of connections per torrent limit must be greater than 0 or disabled.</source>
        <translation>O número máximo do limite de ligações por torrent tem que ser superior a 0 ou estar inativo.</translation>
    </message>
    <message>
        <source>Maximum number of upload slots per torrent limit must be greater than 0 or disabled.</source>
        <translation>O número máximo do limite de ligações para upload por torrent tem que ser superior a 0 ou estar inativo.</translation>
    </message>
    <message>
        <source>Unable to save program preferences, qBittorrent is probably unreachable.</source>
        <translation>Não foi possível guardar as preferências, o qBittorrent está provavelmente inacessível.</translation>
    </message>
    <message>
        <source>IRC: #qbittorrent on Freenode</source>
        <translation>IRC: #qbittorrent no Freenode</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Desconhecido(a)</translation>
    </message>
    <message>
        <source>Share ratio limit must be between 0 and 9998.</source>
        <translation>O limite do rácio de partilha deverá estar situado entre 0 e 9998.</translation>
    </message>
    <message>
        <source>Seeding time limit must be between 0 and 525600 minutes.</source>
        <translation>O limite do tempo a semear deverá estar localizado entre os 0 e os 525600 minutos.</translation>
    </message>
    <message>
        <source>The port used for incoming connections must be between 1 and 65535.</source>
        <translation>A porta utilizada para as receções tem que estar compreendida entre 1 e 65535.</translation>
    </message>
    <message>
        <source>The port used for the Web UI must be between 1 and 65535.</source>
        <translation>A porta utilizada para a interface web tem que estar compreendida entre 1 e 65535.</translation>
    </message>
    <message>
        <source>Unable to log in, qBittorrent is probably unreachable.</source>
        <translation>Não foi possível iniciar sessão, o qBittorrent está provavelmente inacessível.</translation>
    </message>
    <message>
        <source>Invalid Username or Password.</source>
        <translation>Palavra-passe ou utilizador inválido.</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nome de utilizador</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Palavra-passe</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Iniciar sessão</translation>
    </message>
    <message>
        <source>Original authors</source>
        <translation>Autores originais</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Aplicar</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Adicionar</translation>
    </message>
    <message>
        <source>Upload Torrents</source>
        <comment>Upload torrent files to qBittorent using WebUI</comment>
        <translation>Fazer o upload de torrents</translation>
    </message>
    <message>
        <source>Save files to location:</source>
        <translation>Gravar ficheiros em:</translation>
    </message>
    <message>
        <source>Cookie:</source>
        <translation>Cookie:</translation>
    </message>
    <message>
        <source>Type folder here</source>
        <translation>Escreva aqui a pasta</translation>
    </message>
    <message>
        <source>More information</source>
        <translation>Mais informações</translation>
    </message>
    <message>
        <source>Information about certificates</source>
        <translation>Informações acerca dos certificados</translation>
    </message>
    <message>
        <source>Set location</source>
        <translation>Definir localização</translation>
    </message>
    <message>
        <source>Limit upload rate</source>
        <translation>Limitar rácio de upload</translation>
    </message>
    <message>
        <source>Limit download rate</source>
        <translation>Limitar o rácio de download</translation>
    </message>
    <message>
        <source>Rename torrent</source>
        <translation>Renomear torrent</translation>
    </message>
    <message>
        <source>Other...</source>
        <comment>Save Files to: Watch Folder / Default Folder / Other...</comment>
        <translation>Outro...</translation>
    </message>
    <message>
        <source>Monday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Segunda-feira</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Terça-feira</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Quarta-feira</translation>
    </message>
    <message>
        <source>Thursday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Quinta-feira</translation>
    </message>
    <message>
        <source>Friday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Sexta-feira</translation>
    </message>
    <message>
        <source>Saturday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Sábado</translation>
    </message>
    <message>
        <source>Sunday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Domingo</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Terminar sessão</translation>
    </message>
    <message>
        <source>Download Torrents from their URLs or Magnet links</source>
        <translation>Fazer o download de torrents a partir dos seus URLs ou de ligações magnet</translation>
    </message>
    <message>
        <source>Upload local torrent</source>
        <translation>Fazer o upload de torrent local</translation>
    </message>
    <message>
        <source>Are you sure you want to delete the selected torrents from the transfer list?</source>
        <translation>Tem a certeza de que quer eliminar os torrents selecionados da lista de transferência?</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Guardar</translation>
    </message>
    <message>
        <source>qBittorrent client is not reachable</source>
        <translation>O cliente qBittorrent encontra-se inacessível</translation>
    </message>
    <message>
        <source>Global number of upload slots limit must be greater than 0 or disabled.</source>
        <translation>O número global do limite de slots para upload deverá ser superior a 0 ou estar desativado.</translation>
    </message>
    <message>
        <source>Invalid category name:\nPlease do not use any special characters in the category name.</source>
        <translation>Nome de categoria inválido:\nPor favor, não utilize nenhum caracter especial no nome da categoria.</translation>
    </message>
    <message>
        <source>Unable to create category</source>
        <translation>Não foi possível criar a categoria</translation>
    </message>
    <message>
        <source>Upload rate threshold must be greater than 0.</source>
        <translation>O rácio de upload deverá ser superior a 0.</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Editar</translation>
    </message>
    <message>
        <source>Free space: %1</source>
        <translation>Espaço livre: %1</translation>
    </message>
    <message>
        <source>Torrent inactivity timer must be greater than 0.</source>
        <translation>O tempo de inatividade do torrent deverá ser superior a 0.</translation>
    </message>
    <message>
        <source>Saving Management</source>
        <translation>A guardar gestão</translation>
    </message>
    <message>
        <source>Download rate threshold must be greater than 0.</source>
        <translation>O rácio de downloads deverá ser superior a 0.</translation>
    </message>
    <message>
        <source>qBittorrent has been shutdown</source>
        <translation>O qBittorrent foi desligado.</translation>
    </message>
    <message>
        <source>JavaScript Required! You must enable JavaScript for the Web UI to work properly</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Edit</source>
        <translation>Editar</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Ferramentas</translation>
    </message>
    <message>
        <source>File</source>
        <translation>Ficheiro</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Ver</translation>
    </message>
    <message>
        <source>Options...</source>
        <translation>Opções...</translation>
    </message>
    <message>
        <source>Resume</source>
        <translation>Retomar</translation>
    </message>
    <message>
        <source>Minimum Priority</source>
        <translation>Prioridade mínima</translation>
    </message>
    <message>
        <source>Top Priority</source>
        <translation>Prioridade máxima</translation>
    </message>
    <message>
        <source>Decrease Priority</source>
        <translation>Diminuir prioridade</translation>
    </message>
    <message>
        <source>Increase Priority</source>
        <translation>Aumentar prioridade</translation>
    </message>
    <message>
        <source>Top Toolbar</source>
        <translation>Barra superior</translation>
    </message>
    <message>
        <source>Status Bar</source>
        <translation>Barra de estado</translation>
    </message>
    <message>
        <source>Speed in Title Bar</source>
        <translation>Velocidade na barra de título</translation>
    </message>
    <message>
        <source>Donate!</source>
        <translation>Doar!</translation>
    </message>
    <message>
        <source>Resume All</source>
        <translation>Retomar tudo</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation>Estatísticas</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Acerca</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <source>Pause All</source>
        <translation>Pausar tudo</translation>
    </message>
    <message>
        <source>Add Torrent File...</source>
        <translation>Adicionar ficheiro torrent...</translation>
    </message>
    <message>
        <source>Documentation</source>
        <translation>Documentação</translation>
    </message>
    <message>
        <source>Add Torrent Link...</source>
        <translation>Adicionar ligação torrent...</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Sim</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Não</translation>
    </message>
    <message>
        <source>Global Upload Speed Limit</source>
        <translation>Limite global da velocidade para os uploads</translation>
    </message>
    <message>
        <source>Global Download Speed Limit</source>
        <translation>Limite global da velocidade para os downloads</translation>
    </message>
    <message>
        <source>Are you sure you want to quit qBittorrent?</source>
        <translation>Tem a certeza que deseja sair do qBittorrent?</translation>
    </message>
    <message>
        <source>[D: %1, U: %2] qBittorrent %3</source>
        <comment>D = Download; U = Upload; %3 is qBittorrent version</comment>
        <translation>[D: %1, U: %2] qBittorrent %3</translation>
    </message>
    <message>
        <source>Alternative speed limits</source>
        <translation>Limites alternativos de velocidade</translation>
    </message>
    <message>
        <source>Search Engine</source>
        <translation>Motor de pesquisa</translation>
    </message>
    <message>
        <source>Filter torrent list...</source>
        <translation>Filtrar lista de torrents...</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Pesquisar</translation>
    </message>
    <message>
        <source>Transfers</source>
        <translation>Transferências</translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Opções</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Downloads</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation>Ligação</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Velocidade</translation>
    </message>
    <message>
        <source>BitTorrent</source>
        <translation>BitTorrent</translation>
    </message>
    <message>
        <source>Web UI</source>
        <translation>Interface Web</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Idioma</translation>
    </message>
    <message>
        <source>User Interface Language:</source>
        <translation>Idioma da interface do utilizador:</translation>
    </message>
    <message>
        <source>Email notification upon download completion</source>
        <translation>Enviar notificação por e-mail ao terminar o download</translation>
    </message>
    <message>
        <source>Run external program on torrent completion</source>
        <translation>Correr programa externo ao terminar o torrent</translation>
    </message>
    <message>
        <source>IP Filtering</source>
        <translation>Filtro de IP</translation>
    </message>
    <message>
        <source>Schedule the use of alternative rate limits</source>
        <translation>Agendar a utilização dos limites de rácio alternativos</translation>
    </message>
    <message>
        <source>Torrent Queueing</source>
        <translation>Fila de torrents</translation>
    </message>
    <message>
        <source>Seed torrents until their seeding time reaches</source>
        <translation>Semear os torrents até ser atingido o seu tempo de sementeira</translation>
    </message>
    <message>
        <source>Automatically add these trackers to new downloads:</source>
        <translation>Adicionar automaticamente estes trackers aos novos downloads:</translation>
    </message>
    <message>
        <source>Web User Interface (Remote control)</source>
        <translation>Interface web do utilizador (controlo remoto)</translation>
    </message>
    <message>
        <source>IP address:</source>
        <translation>Endereço IP:</translation>
    </message>
    <message>
        <source>Server domains:</source>
        <translation>Domínio do servidor:</translation>
    </message>
    <message>
        <source>Use HTTPS instead of HTTP</source>
        <translation>Utilizar o HTTPS como alternativa ao HTTP</translation>
    </message>
    <message>
        <source>Bypass authentication for clients on localhost</source>
        <translation>Desativar a autenticação para clientes no localhost</translation>
    </message>
    <message>
        <source>Bypass authentication for clients in whitelisted IP subnets</source>
        <translation>Desativar a autenticação para clientes pertencentes à lista de IPs confiáveis</translation>
    </message>
    <message>
        <source>Update my dynamic domain name</source>
        <translation>Atualizar o nome de domínio dinâmico</translation>
    </message>
    <message>
        <source>Keep incomplete torrents in:</source>
        <translation>Guardar os torrents incompletos em:</translation>
    </message>
    <message>
        <source>Copy .torrent files to:</source>
        <translation>Copiar os ficheiros .torrent para:</translation>
    </message>
    <message>
        <source>Copy .torrent files for finished downloads to:</source>
        <translation>Copiar os ficheiros .torrent dos downloads terminados para:</translation>
    </message>
    <message>
        <source>Pre-allocate disk space for all files</source>
        <translation>Pré-alocar espaço em disco para todos os ficheiros</translation>
    </message>
    <message>
        <source>Append .!qB extension to incomplete files</source>
        <translation>Adicionar a extensão .!qB aos ficheiros incompletos</translation>
    </message>
    <message>
        <source>Automatically add torrents from:</source>
        <translation>Adicionar automaticamente os torrents de:</translation>
    </message>
    <message>
        <source>SMTP server:</source>
        <translation>Servidor SMTP:</translation>
    </message>
    <message>
        <source>This server requires a secure connection (SSL)</source>
        <translation>Este servidor requer uma ligação segura (SSL)</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation>Autenticação</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Nome de utilizador:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Palavra-passe:</translation>
    </message>
    <message>
        <source>Enabled protocol:</source>
        <translation>Ativar o protocolo:</translation>
    </message>
    <message>
        <source>TCP and μTP</source>
        <translation>TCP e μTP</translation>
    </message>
    <message>
        <source>Listening Port</source>
        <translation>Porta de receção</translation>
    </message>
    <message>
        <source>Port used for incoming connections:</source>
        <translation>Porta utilizada para as ligações recebidas:</translation>
    </message>
    <message>
        <source>Use UPnP / NAT-PMP port forwarding from my router</source>
        <translation>Utilizar o reencaminhamento de portas UPnP/NAT-PMP do meu router</translation>
    </message>
    <message>
        <source>Use different port on each startup</source>
        <translation>Utilizar uma porta diferente a cada arranque</translation>
    </message>
    <message>
        <source>Connections Limits</source>
        <translation>Limites das ligações</translation>
    </message>
    <message>
        <source>Maximum number of connections per torrent:</source>
        <translation>Número máximo de ligações por torrent:</translation>
    </message>
    <message>
        <source>Global maximum number of connections:</source>
        <translation>Número máximo de ligações globais:</translation>
    </message>
    <message>
        <source>Maximum number of upload slots per torrent:</source>
        <translation>Número máximo de slots de upload por torrent:</translation>
    </message>
    <message>
        <source>Global maximum number of upload slots:</source>
        <translation>Número máximo de slots de upload por torrent:</translation>
    </message>
    <message>
        <source>Proxy Server</source>
        <translation>Servidor proxy</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Tipo:</translation>
    </message>
    <message>
        <source>(None)</source>
        <translation>(Nenhum(a))</translation>
    </message>
    <message>
        <source>SOCKS4</source>
        <translation>SOCKS4</translation>
    </message>
    <message>
        <source>SOCKS5</source>
        <translation>SOCKS5</translation>
    </message>
    <message>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <source>Host:</source>
        <translation>Servidor:</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>Porta:</translation>
    </message>
    <message>
        <source>Use proxy for peer connections</source>
        <translation>Utilizar um proxy para ligações às fontes</translation>
    </message>
    <message>
        <source>Disable connections not supported by proxies</source>
        <translation>Desativar as ligações não suportadas pelos proxies</translation>
    </message>
    <message>
        <source>Use proxy only for torrents</source>
        <translation>Utilizar um proxy apenas para torrents</translation>
    </message>
    <message>
        <source>Filter path (.dat, .p2p, .p2b):</source>
        <translation>Filtrar caminho (.dat, .p2p, .p2b):</translation>
    </message>
    <message>
        <source>Manually banned IP addresses...</source>
        <translation>Endereços de IP banidos manualmente...</translation>
    </message>
    <message>
        <source>Apply to trackers</source>
        <translation>Aplicar aos trackers</translation>
    </message>
    <message>
        <source>Global Rate Limits</source>
        <translation>Limites de rácio globais</translation>
    </message>
    <message>
        <source>Upload:</source>
        <translation>Upload:</translation>
    </message>
    <message>
        <source>Download:</source>
        <translation>Download:</translation>
    </message>
    <message>
        <source>Alternative Rate Limits</source>
        <translation>Limites alternativos de rácio</translation>
    </message>
    <message>
        <source>From:</source>
        <extracomment>from (time1 to time2)</extracomment>
        <translation>De:</translation>
    </message>
    <message>
        <source>To:</source>
        <extracomment>time1 to time2</extracomment>
        <translation>Para:</translation>
    </message>
    <message>
        <source>When:</source>
        <translation>Quando:</translation>
    </message>
    <message>
        <source>Every day</source>
        <translation>Diariamente </translation>
    </message>
    <message>
        <source>Weekdays</source>
        <translation>Dias da semana</translation>
    </message>
    <message>
        <source>Weekends</source>
        <translation>Fins de semana</translation>
    </message>
    <message>
        <source>Rate Limits Settings</source>
        <translation>Definições dos limites de rácio</translation>
    </message>
    <message>
        <source>Apply rate limit to transport overhead</source>
        <translation>Aplicar os limites de rácio para o transporte "overhead"</translation>
    </message>
    <message>
        <source>Apply rate limit to µTP protocol</source>
        <translation>Aplicar os limites de rácio ao protocolo µTP</translation>
    </message>
    <message>
        <source>Privacy</source>
        <translation>Privacidade</translation>
    </message>
    <message>
        <source>Enable DHT (decentralized network) to find more peers</source>
        <translation>Ativar DHT (rede descentralizada) para encontrar mais fontes</translation>
    </message>
    <message>
        <source>Enable Peer Exchange (PeX) to find more peers</source>
        <translation>Ativar a 'Troca de Fontes' (PeX) para encontrar mais fontes</translation>
    </message>
    <message>
        <source>Enable Local Peer Discovery to find more peers</source>
        <translation>Ativar 'Descoberta de fontes locais' para encontrar mais fontes</translation>
    </message>
    <message>
        <source>Encryption mode:</source>
        <translation>Modo de encriptação:</translation>
    </message>
    <message>
        <source>Prefer encryption</source>
        <translation>Preferir encriptação</translation>
    </message>
    <message>
        <source>Require encryption</source>
        <translation>Requer encriptação</translation>
    </message>
    <message>
        <source>Disable encryption</source>
        <translation>Desativar encriptação</translation>
    </message>
    <message>
        <source>Enable anonymous mode</source>
        <translation>Ativar o modo anónimo</translation>
    </message>
    <message>
        <source>Maximum active downloads:</source>
        <translation>Nº máximo de downloads ativos:</translation>
    </message>
    <message>
        <source>Maximum active uploads:</source>
        <translation>Nº máximo de uploads ativos:</translation>
    </message>
    <message>
        <source>Maximum active torrents:</source>
        <translation>Nº máximo de torrents ativos:</translation>
    </message>
    <message>
        <source>Do not count slow torrents in these limits</source>
        <translation>Não considerar os torrents lentos para estes limites</translation>
    </message>
    <message>
        <source>Share Ratio Limiting</source>
        <translation>Limite do rácio de partilhas</translation>
    </message>
    <message>
        <source>Seed torrents until their ratio reaches</source>
        <translation>Partilhar torrents até que o rácio atinja</translation>
    </message>
    <message>
        <source>then</source>
        <translation>depois</translation>
    </message>
    <message>
        <source>Pause them</source>
        <translation>Pausá-los</translation>
    </message>
    <message>
        <source>Remove them</source>
        <translation>Removê-los</translation>
    </message>
    <message>
        <source>Use UPnP / NAT-PMP to forward the port from my router</source>
        <translation>Utilizar o reencaminhamento de portas UPnP/NAT-PMP do meu router</translation>
    </message>
    <message>
        <source>Certificate:</source>
        <translation>Certificado:</translation>
    </message>
    <message>
        <source>Key:</source>
        <translation>Chave:</translation>
    </message>
    <message>
        <source>Register</source>
        <translation>Registar</translation>
    </message>
    <message>
        <source>Domain name:</source>
        <translation>Nome do domínio:</translation>
    </message>
    <message>
        <source>Supported parameters (case sensitive):</source>
        <translation>Parâmetros suportados (sensível a maiúsculas/minúsculas):</translation>
    </message>
    <message>
        <source>%N: Torrent name</source>
        <translation>%N: Nome do torrent</translation>
    </message>
    <message>
        <source>%L: Category</source>
        <translation>%L: Categoria</translation>
    </message>
    <message>
        <source>%G: Tags (seperated by comma)</source>
        <translation>%G: Etiquetas (separadas por vírgula)</translation>
    </message>
    <message>
        <source>%F: Content path (same as root path for multifile torrent)</source>
        <translation>%F: Caminho do conteúdo (igual ao caminho raiz para torrents de vários ficheiros)</translation>
    </message>
    <message>
        <source>%R: Root path (first torrent subdirectory path)</source>
        <translation>%R: Caminho raiz (caminho da primeira subdiretoria do torrent)</translation>
    </message>
    <message>
        <source>%D: Save path</source>
        <translation>%D: Caminho para gravar</translation>
    </message>
    <message>
        <source>%C: Number of files</source>
        <translation>%C: Número de ficheiros</translation>
    </message>
    <message>
        <source>%Z: Torrent size (bytes)</source>
        <translation>%Z: Tamanho do torrent (bytes)</translation>
    </message>
    <message>
        <source>%T: Current tracker</source>
        <translation>%T: Tracker atual</translation>
    </message>
    <message>
        <source>%I: Info hash</source>
        <translation>%I: Info hash</translation>
    </message>
    <message>
        <source>Tip: Encapsulate parameter with quotation marks to avoid text being cut off at whitespace (e.g., "%N")</source>
        <translation>Dica: Encapsule o parâmetro entre aspas para evitar que sejam cortados os espaços em branco do texto (ex: "%N")</translation>
    </message>
    <message>
        <source>The Web UI username must be at least 3 characters long.</source>
        <translation>O nome de utilizador da interface web deverá conter pelo menos 3 carateres.</translation>
    </message>
    <message>
        <source>The Web UI password must be at least 6 characters long.</source>
        <translation>A palavra-passe da interface web deverá conter pelo menos 6 caracteres.</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>minutos</translation>
    </message>
    <message>
        <source>KiB/s</source>
        <translation>KiB/s</translation>
    </message>
    <message>
        <source>Enable clickjacking protection</source>
        <translation>Ativar a proteção contra o "clickjacking"</translation>
    </message>
    <message>
        <source>Enable Cross-Site Request Forgery (CSRF) protection</source>
        <translation>Ativar a proteção contra falsificação de solicitação entre sites (CSRF)</translation>
    </message>
    <message>
        <source>Delete .torrent files afterwards</source>
        <translation>Eliminar mais tarde os ficheiros .torrent</translation>
    </message>
    <message>
        <source>Download rate threshold:</source>
        <translation>Limite do rácio de download:</translation>
    </message>
    <message>
        <source>Upload rate threshold:</source>
        <translation>Limite do rácio de upload:</translation>
    </message>
    <message>
        <source>Change current password</source>
        <translation>Alterar a palavra-passe atual</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation>Automático</translation>
    </message>
    <message>
        <source>Use alternative Web UI</source>
        <translation>Utilizar interface web alternativa</translation>
    </message>
    <message>
        <source>Default Save Path:</source>
        <translation>Caminho padrão para o 'Guardar':</translation>
    </message>
    <message>
        <source>The alternative Web UI files location cannot be blank.</source>
        <translation>A localização dos ficheiros alternativos da interface web não pode estar em branco.</translation>
    </message>
    <message>
        <source>Do not start the download automatically</source>
        <translation>Não iniciar automaticamente o download</translation>
    </message>
    <message>
        <source>Switch torrent to Manual Mode</source>
        <translation>Mudar torrent para o 'Modo manual'</translation>
    </message>
    <message>
        <source>When Torrent Category changed:</source>
        <translation>Quando a 'Categoria do torrent' for alterada:</translation>
    </message>
    <message>
        <source>Relocate affected torrents</source>
        <translation>Realocar torrents afetados</translation>
    </message>
    <message>
        <source>Apply rate limit to peers on LAN</source>
        <translation>Aplicar o rácio limite para as fontes em LAN</translation>
    </message>
    <message>
        <source>0 means unlimited</source>
        <translation>0 significa ilimitado</translation>
    </message>
    <message>
        <source>Relocate torrent</source>
        <translation>Realocar torrent</translation>
    </message>
    <message>
        <source>When Default Save Path changed:</source>
        <translation>Quando o 'Caminho padrão para guardar' for alterado:</translation>
    </message>
    <message>
        <source>Enable Host header validation</source>
        <translation>Ativar a validação do cabeçalho do servidor</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Segurança</translation>
    </message>
    <message>
        <source>When Category Save Path changed:</source>
        <translation>Quando alterar a 'Categoria do caminho para guardar':</translation>
    </message>
    <message>
        <source>Create subfolder for torrents with multiple files</source>
        <translation>Criar uma subpasta para os torrents com vários ficheiros</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>segundos</translation>
    </message>
    <message>
        <source>Switch affected torrents to Manual Mode</source>
        <translation>Mudar os torrents afetados para o 'Modo manual'</translation>
    </message>
    <message>
        <source>Files location:</source>
        <translation>Localização dos ficheiros:</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manual</translation>
    </message>
    <message>
        <source>Torrent inactivity timer:</source>
        <translation>Temporizador de inatividade do torrent:</translation>
    </message>
    <message>
        <source>Default Torrent Management Mode:</source>
        <translation>Modo de gestão do torrent por defeito:</translation>
    </message>
    <message>
        <source>When adding a torrent</source>
        <translation>Ao adicionar um torrent</translation>
    </message>
</context>
<context>
    <name>PeerListWidget</name>
    <message>
        <source>IP</source>
        <translation>IP</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Porta</translation>
    </message>
    <message>
        <source>Flags</source>
        <translation>Bandeiras</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation>Ligação</translation>
    </message>
    <message>
        <source>Client</source>
        <comment>i.e.: Client application</comment>
        <translation>Cliente</translation>
    </message>
    <message>
        <source>Progress</source>
        <comment>i.e: % downloaded</comment>
        <translation>Evolução</translation>
    </message>
    <message>
        <source>Down Speed</source>
        <comment>i.e: Download speed</comment>
        <translation>Vel. download</translation>
    </message>
    <message>
        <source>Up Speed</source>
        <comment>i.e: Upload speed</comment>
        <translation>Vel. upload</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <comment>i.e: total data downloaded</comment>
        <translation>Descarregado</translation>
    </message>
    <message>
        <source>Uploaded</source>
        <comment>i.e: total data uploaded</comment>
        <translation>Enviado</translation>
    </message>
    <message>
        <source>Relevance</source>
        <comment>i.e: How relevant this peer is to us. How many pieces it has that we don't.</comment>
        <translation>Importância</translation>
    </message>
    <message>
        <source>Files</source>
        <comment>i.e. files that are being downloaded right now</comment>
        <translation>Ficheiros</translation>
    </message>
    <message>
        <source>Country</source>
        <translation>País</translation>
    </message>
</context>
<context>
    <name>PropListDelegate</name>
    <message>
        <source>Normal</source>
        <comment>Normal (priority)</comment>
        <translation>Normal</translation>
    </message>
    <message>
        <source>High</source>
        <comment>High (priority)</comment>
        <translation>Alta</translation>
    </message>
    <message>
        <source>Maximum</source>
        <comment>Maximum (priority)</comment>
        <translation>Máxima</translation>
    </message>
</context>
<context>
    <name>PropTabBar</name>
    <message>
        <source>General</source>
        <translation>Geral</translation>
    </message>
    <message>
        <source>Trackers</source>
        <translation>Trackers</translation>
    </message>
    <message>
        <source>Peers</source>
        <translation>Fontes</translation>
    </message>
    <message>
        <source>HTTP Sources</source>
        <translation>Fontes HTTP</translation>
    </message>
    <message>
        <source>Content</source>
        <translation>Conteúdo</translation>
    </message>
</context>
<context>
    <name>PropertiesWidget</name>
    <message>
        <source>Downloaded:</source>
        <translation>Descarregado:</translation>
    </message>
    <message>
        <source>Transfer</source>
        <translation>Transferir</translation>
    </message>
    <message>
        <source>Time Active:</source>
        <extracomment>Time (duration) the torrent is active (not paused)</extracomment>
        <translation>Ativo há:</translation>
    </message>
    <message>
        <source>ETA:</source>
        <translation>TEF:</translation>
    </message>
    <message>
        <source>Uploaded:</source>
        <translation>Enviados:</translation>
    </message>
    <message>
        <source>Seeds:</source>
        <translation>Sementes:</translation>
    </message>
    <message>
        <source>Download Speed:</source>
        <translation>Vel. de download:</translation>
    </message>
    <message>
        <source>Upload Speed:</source>
        <translation>Vel. de upload:</translation>
    </message>
    <message>
        <source>Peers:</source>
        <translation>Fontes:</translation>
    </message>
    <message>
        <source>Download Limit:</source>
        <translation>Limite de download:</translation>
    </message>
    <message>
        <source>Upload Limit:</source>
        <translation>Limite de upload:</translation>
    </message>
    <message>
        <source>Wasted:</source>
        <translation>Perdido:</translation>
    </message>
    <message>
        <source>Connections:</source>
        <translation>Ligações:</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Informações</translation>
    </message>
    <message>
        <source>Comment:</source>
        <translation>Comentário:</translation>
    </message>
    <message>
        <source>Share Ratio:</source>
        <translation>Rácio de partilha:</translation>
    </message>
    <message>
        <source>Reannounce In:</source>
        <translation>Reanunciar em:</translation>
    </message>
    <message>
        <source>Last Seen Complete:</source>
        <translation>Última vez que esteve completo:</translation>
    </message>
    <message>
        <source>Total Size:</source>
        <translation>Tamanho total:</translation>
    </message>
    <message>
        <source>Pieces:</source>
        <translation>Peças:</translation>
    </message>
    <message>
        <source>Created By:</source>
        <translation>Criado por:</translation>
    </message>
    <message>
        <source>Added On:</source>
        <translation>Adicionado em:</translation>
    </message>
    <message>
        <source>Completed On:</source>
        <translation>Terminado em:</translation>
    </message>
    <message>
        <source>Created On:</source>
        <translation>Criado em:</translation>
    </message>
    <message>
        <source>Torrent Hash:</source>
        <translation>Hash do torrent:</translation>
    </message>
    <message>
        <source>Save Path:</source>
        <translation>Guardado em:</translation>
    </message>
    <message>
        <source>Never</source>
        <translation>Nunca</translation>
    </message>
    <message>
        <source>%1 x %2 (have %3)</source>
        <comment>(torrent pieces) eg 152 x 4MB (have 25)</comment>
        <translation>%1 x %2 (tem %3)</translation>
    </message>
    <message>
        <source>%1 (%2 this session)</source>
        <translation>%1 (%2 nesta sessão)</translation>
    </message>
    <message>
        <source>%1 (%2 max)</source>
        <comment>%1 and %2 are numbers, e.g. 3 (10 max)</comment>
        <translation>%1 (máximo: %2)</translation>
    </message>
    <message>
        <source>%1 (%2 total)</source>
        <comment>%1 and %2 are numbers, e.g. 3 (10 total)</comment>
        <translation>%1 (total: %2)</translation>
    </message>
    <message>
        <source>%1 (%2 avg.)</source>
        <comment>%1 and %2 are speed rates, e.g. 200KiB/s (100KiB/s avg.)</comment>
        <translation>%1 (média: %2)</translation>
    </message>
    <message>
        <source>Download limit:</source>
        <translation>Limite de download:</translation>
    </message>
    <message>
        <source>Upload limit:</source>
        <translation>Limite de upload:</translation>
    </message>
</context>
<context>
    <name>ScanFoldersModel</name>
    <message>
        <source>Monitored Folder</source>
        <translation>Pasta monitorizada</translation>
    </message>
    <message>
        <source>Override Save Location</source>
        <translation>Sobrepor o local para guardar</translation>
    </message>
    <message>
        <source>Monitored folder</source>
        <translation>Pasta monitorizada</translation>
    </message>
    <message>
        <source>Default save location</source>
        <translation>Local por defeito para o 'Guardar'</translation>
    </message>
</context>
<context>
    <name>SpeedLimitDialog</name>
    <message>
        <source>KiB/s</source>
        <translation>KiB/s</translation>
    </message>
</context>
<context>
    <name>StatsDialog</name>
    <message>
        <source>Statistics</source>
        <translation>Estatísticas</translation>
    </message>
    <message>
        <source>User statistics</source>
        <translation>Estatísticas do utilizador</translation>
    </message>
    <message>
        <source>Cache statistics</source>
        <translation>Estatísticas de cache</translation>
    </message>
    <message>
        <source>Read cache hits:</source>
        <translation>Tops de leituras da cache:</translation>
    </message>
    <message>
        <source>Average time in queue:</source>
        <translation>Tempo médio em fila:</translation>
    </message>
    <message>
        <source>Connected peers:</source>
        <translation>Fontes ligadas:</translation>
    </message>
    <message>
        <source>All-time share ratio:</source>
        <translation>Taxa de partilha global:</translation>
    </message>
    <message>
        <source>All-time download:</source>
        <translation>Downloads globais:</translation>
    </message>
    <message>
        <source>Session waste:</source>
        <translation>Desperdício da sessão:</translation>
    </message>
    <message>
        <source>All-time upload:</source>
        <translation>Uploads globais:</translation>
    </message>
    <message>
        <source>Total buffer size:</source>
        <translation>Tamanho total do buffer:</translation>
    </message>
    <message>
        <source>Performance statistics</source>
        <translation>Estatísticas de desempenho</translation>
    </message>
    <message>
        <source>Queued I/O jobs:</source>
        <translation>Tarefas I/O na fila:</translation>
    </message>
    <message>
        <source>Write cache overload:</source>
        <translation>Excesso de escrita em cache:</translation>
    </message>
    <message>
        <source>Read cache overload:</source>
        <translation>Excesso de leitura em cache:</translation>
    </message>
    <message>
        <source>Total queued size:</source>
        <translation>Tamanho total da fila:</translation>
    </message>
</context>
<context>
    <name>StatusBar</name>
    <message>
        <source>DHT: %1 nodes</source>
        <translation>DHT: %1 nós</translation>
    </message>
</context>
<context>
    <name>StatusFilterWidget</name>
    <message>
        <source>All (0)</source>
        <comment>this is for the status filter</comment>
        <translation>Tudo (0)</translation>
    </message>
    <message>
        <source>Downloading (0)</source>
        <translation>A fazer o download (0)</translation>
    </message>
    <message>
        <source>Seeding (0)</source>
        <translation>A semar (0)</translation>
    </message>
    <message>
        <source>Completed (0)</source>
        <translation>Terminado (0)</translation>
    </message>
    <message>
        <source>Resumed (0)</source>
        <translation>Retomado (0)</translation>
    </message>
    <message>
        <source>Paused (0)</source>
        <translation>Em pausa (0)</translation>
    </message>
    <message>
        <source>Active (0)</source>
        <translation>Ativos (0)</translation>
    </message>
    <message>
        <source>Inactive (0)</source>
        <translation>Inativos (0)</translation>
    </message>
    <message>
        <source>Errored (0)</source>
        <translation>Com erro (0)</translation>
    </message>
    <message>
        <source>All (%1)</source>
        <translation>Tudo (%1)</translation>
    </message>
    <message>
        <source>Downloading (%1)</source>
        <translation>A fazer o download (%1)</translation>
    </message>
    <message>
        <source>Seeding (%1)</source>
        <translation> A semear (%1)</translation>
    </message>
    <message>
        <source>Completed (%1)</source>
        <translation>Terminados (%1)</translation>
    </message>
    <message>
        <source>Paused (%1)</source>
        <translation>Em pausa (%1)</translation>
    </message>
    <message>
        <source>Resumed (%1)</source>
        <translation>Retomados (%1)</translation>
    </message>
    <message>
        <source>Active (%1)</source>
        <translation>Ativos (%1)</translation>
    </message>
    <message>
        <source>Inactive (%1)</source>
        <translation>Inativos (%1)</translation>
    </message>
    <message>
        <source>Errored (%1)</source>
        <translation>Com erro (%1)</translation>
    </message>
</context>
<context>
    <name>TorrentContentModel</name>
    <message>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Tamanho</translation>
    </message>
    <message>
        <source>Progress</source>
        <translation>Evolução</translation>
    </message>
    <message>
        <source>Download Priority</source>
        <translation>Prioridade dos downloads</translation>
    </message>
    <message>
        <source>Remaining</source>
        <translation>Restante</translation>
    </message>
    <message>
        <source>Availability</source>
        <translation>Disponibilidade</translation>
    </message>
</context>
<context>
    <name>TransferListModel</name>
    <message>
        <source>Name</source>
        <comment>i.e: torrent name</comment>
        <translation>Nome</translation>
    </message>
    <message>
        <source>Size</source>
        <comment>i.e: torrent size</comment>
        <translation>Tamanho</translation>
    </message>
    <message>
        <source>Done</source>
        <comment>% Done</comment>
        <translation>Concluído</translation>
    </message>
    <message>
        <source>Status</source>
        <comment>Torrent status (e.g. downloading, seeding, paused)</comment>
        <translation>Estado</translation>
    </message>
    <message>
        <source>Seeds</source>
        <comment>i.e. full sources (often untranslated)</comment>
        <translation>Sementes</translation>
    </message>
    <message>
        <source>Peers</source>
        <comment>i.e. partial sources (often untranslated)</comment>
        <translation>Fontes</translation>
    </message>
    <message>
        <source>Down Speed</source>
        <comment>i.e: Download speed</comment>
        <translation>Vel. download</translation>
    </message>
    <message>
        <source>Up Speed</source>
        <comment>i.e: Upload speed</comment>
        <translation>Vel. upload</translation>
    </message>
    <message>
        <source>Ratio</source>
        <comment>Share ratio</comment>
        <translation>Rácio</translation>
    </message>
    <message>
        <source>ETA</source>
        <comment>i.e: Estimated Time of Arrival / Time left</comment>
        <translation>TEF</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>Categoria</translation>
    </message>
    <message>
        <source>Tags</source>
        <translation>Etiquetas</translation>
    </message>
    <message>
        <source>Added On</source>
        <comment>Torrent was added to transfer list on 01/01/2010 08:00</comment>
        <translation>Adicionado em</translation>
    </message>
    <message>
        <source>Completed On</source>
        <comment>Torrent was completed on 01/01/2010 08:00</comment>
        <translation>Concluído em</translation>
    </message>
    <message>
        <source>Tracker</source>
        <translation>Tracker</translation>
    </message>
    <message>
        <source>Down Limit</source>
        <comment>i.e: Download limit</comment>
        <translation>Limite de downloads</translation>
    </message>
    <message>
        <source>Up Limit</source>
        <comment>i.e: Upload limit</comment>
        <translation>Limite de uploads</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <comment>Amount of data downloaded (e.g. in MB)</comment>
        <translation>Descarregado</translation>
    </message>
    <message>
        <source>Uploaded</source>
        <comment>Amount of data uploaded (e.g. in MB)</comment>
        <translation>Enviado</translation>
    </message>
    <message>
        <source>Session Download</source>
        <comment>Amount of data downloaded since program open (e.g. in MB)</comment>
        <translation>Dados recebidos</translation>
    </message>
    <message>
        <source>Session Upload</source>
        <comment>Amount of data uploaded since program open (e.g. in MB)</comment>
        <translation>Dados enviados</translation>
    </message>
    <message>
        <source>Remaining</source>
        <comment>Amount of data left to download (e.g. in MB)</comment>
        <translation>Restante</translation>
    </message>
    <message>
        <source>Time Active</source>
        <comment>Time (duration) the torrent is active (not paused)</comment>
        <translation>Tempo ativo</translation>
    </message>
    <message>
        <source>Save path</source>
        <comment>Torrent save path</comment>
        <translation>Guardar em</translation>
    </message>
    <message>
        <source>Completed</source>
        <comment>Amount of data completed (e.g. in MB)</comment>
        <translation>Terminado</translation>
    </message>
    <message>
        <source>Ratio Limit</source>
        <comment>Upload share ratio limit</comment>
        <translation>Limite do rácio</translation>
    </message>
    <message>
        <source>Last Seen Complete</source>
        <comment>Indicates the time when the torrent was last seen complete/whole</comment>
        <translation>Última vez que o ficheiro esteve completo</translation>
    </message>
    <message>
        <source>Last Activity</source>
        <comment>Time passed since a chunk was downloaded/uploaded</comment>
        <translation>Última atividade</translation>
    </message>
    <message>
        <source>Total Size</source>
        <comment>i.e. Size including unwanted data</comment>
        <translation>Tamanho total</translation>
    </message>
</context>
<context>
    <name>TrackerListWidget</name>
    <message>
        <source>URL</source>
        <translation>URL</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Estado</translation>
    </message>
    <message>
        <source>Peers</source>
        <translation>Fontes</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Mensagem</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <translation>Transferido(s)</translation>
    </message>
    <message>
        <source>Tracker URL:</source>
        <translation>URL do tracker:</translation>
    </message>
    <message>
        <source>Updating...</source>
        <translation>A atualizar...</translation>
    </message>
    <message>
        <source>Working</source>
        <translation>A executar</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Inativo</translation>
    </message>
    <message>
        <source>Not contacted yet</source>
        <translation>Ainda não contactado</translation>
    </message>
    <message>
        <source>#</source>
        <translation>#</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>N/D</translation>
    </message>
    <message>
        <source>Seeds</source>
        <translation>Sementes</translation>
    </message>
    <message>
        <source>Not working</source>
        <translation>Parado</translation>
    </message>
    <message>
        <source>Copy tracker URL</source>
        <translation>Copiar URL do tracker</translation>
    </message>
    <message>
        <source>Add a new tracker...</source>
        <translation>Adicionar novo tracker...</translation>
    </message>
    <message>
        <source>Edit tracker URL...</source>
        <translation>Editar URL do tracker...</translation>
    </message>
    <message>
        <source>Tracker editing</source>
        <translation>Editar tracker</translation>
    </message>
    <message>
        <source>Leeches</source>
        <translation>Sanguessuga</translation>
    </message>
    <message>
        <source>Remove tracker</source>
        <translation>Remover tracker</translation>
    </message>
</context>
<context>
    <name>TrackersAdditionDialog</name>
    <message>
        <source>Trackers addition dialog</source>
        <translation>Diálogo de adição de trackers</translation>
    </message>
    <message>
        <source>List of trackers to add (one per line):</source>
        <translation>Lista de trackers a adicionar (um por linha):</translation>
    </message>
</context>
<context>
    <name>TransferListDelegate</name>
    <message>
        <source>%1 ago</source>
        <comment>e.g.: 1h 20m ago</comment>
        <translation>%1 atrás</translation>
    </message>
    <message>
        <source>Allocating</source>
        <translation>A alocar</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>Em pausa</translation>
    </message>
    <message>
        <source>Completed</source>
        <translation>Terminado(s)</translation>
    </message>
    <message>
        <source>Moving</source>
        <translation>A mover</translation>
    </message>
    <message>
        <source>[F] Seeding</source>
        <translation>[F] A semear</translation>
    </message>
    <message>
        <source>Seeding</source>
        <translation>A semear</translation>
    </message>
    <message>
        <source>Queued</source>
        <translation>Em fila</translation>
    </message>
    <message>
        <source>Errored</source>
        <translation>Com erro</translation>
    </message>
    <message>
        <source>[F] Downloading</source>
        <translation>[F] A fazer o download</translation>
    </message>
    <message>
        <source>Downloading metadata</source>
        <translation>A fazer o download dos metadados</translation>
    </message>
    <message>
        <source>Checking</source>
        <translation>A verificar</translation>
    </message>
    <message>
        <source>Missing Files</source>
        <translation>Ficheiros em falta</translation>
    </message>
    <message>
        <source>Queued for checking</source>
        <translation>Na fila de verificação</translation>
    </message>
    <message>
        <source>Downloading</source>
        <translation>A fazer o download</translation>
    </message>
    <message>
        <source>Checking resume data</source>
        <translation>A analisar dados</translation>
    </message>
    <message>
        <source>Stalled</source>
        <translation>Em espera</translation>
    </message>
</context>
<context>
    <name>TransferListFiltersWidget</name>
    <message>
        <source>Status</source>
        <translation>Estado</translation>
    </message>
    <message>
        <source>Categories</source>
        <translation>Categorias</translation>
    </message>
</context>
<context>
    <name>TransferListWidget</name>
    <message>
        <source>Torrent Download Speed Limiting</source>
        <translation>Limite de velocidade para o download dos torrents</translation>
    </message>
    <message>
        <source>Torrent Upload Speed Limiting</source>
        <translation>Limite de velocidade para o upload de torrents</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Renomear</translation>
    </message>
    <message>
        <source>Resume</source>
        <comment>Resume/start the torrent</comment>
        <translation>Retomar</translation>
    </message>
    <message>
        <source>Force Resume</source>
        <comment>Force Resume/start the torrent</comment>
        <translation>Forçar continuação</translation>
    </message>
    <message>
        <source>Pause</source>
        <comment>Pause the torrent</comment>
        <translation>Pausar</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>Delete the torrent</comment>
        <translation>Eliminar</translation>
    </message>
    <message>
        <source>Limit share ratio...</source>
        <translation>Limitar o rácio de partilha...</translation>
    </message>
    <message>
        <source>Limit upload rate...</source>
        <translation>Limitar rácio de upload...</translation>
    </message>
    <message>
        <source>Limit download rate...</source>
        <translation>Limitar o rácio de download...</translation>
    </message>
    <message>
        <source>Move up</source>
        <comment>i.e. move up in the queue</comment>
        <translation>Mover para cima</translation>
    </message>
    <message>
        <source>Move down</source>
        <comment>i.e. Move down in the queue</comment>
        <translation>Mover para baixo</translation>
    </message>
    <message>
        <source>Move to top</source>
        <comment>i.e. Move to top of the queue</comment>
        <translation>Mover para o início</translation>
    </message>
    <message>
        <source>Move to bottom</source>
        <comment>i.e. Move to bottom of the queue</comment>
        <translation>Mover para o fim</translation>
    </message>
    <message>
        <source>Set location...</source>
        <translation>Definir localização...</translation>
    </message>
    <message>
        <source>Copy name</source>
        <translation>Copiar nome</translation>
    </message>
    <message>
        <source>Copy hash</source>
        <translation>Copiar hash</translation>
    </message>
    <message>
        <source>Download first and last pieces first</source>
        <translation>Fazer o download da primeira e última peça primeiro</translation>
    </message>
    <message>
        <source>Automatic Torrent Management</source>
        <translation>Gestão automática do torrent</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>Categoria</translation>
    </message>
    <message>
        <source>New...</source>
        <comment>New category...</comment>
        <translation>Novo(a)...</translation>
    </message>
    <message>
        <source>Reset</source>
        <comment>Reset category</comment>
        <translation>Redefinir</translation>
    </message>
    <message>
        <source>Priority</source>
        <translation>Prioridade</translation>
    </message>
    <message>
        <source>Force recheck</source>
        <translation>Forçar nova verificação</translation>
    </message>
    <message>
        <source>Copy magnet link</source>
        <translation>Copiar ligação magnet</translation>
    </message>
    <message>
        <source>Super seeding mode</source>
        <translation>Modo super semeador</translation>
    </message>
    <message>
        <source>Rename...</source>
        <translation>Renomear...</translation>
    </message>
    <message>
        <source>Download in sequential order</source>
        <translation>Fazer o download sequencialmente</translation>
    </message>
    <message>
        <source>Force Recheck</source>
        <translation>Forçar nova verificação</translation>
    </message>
    <message>
        <source>New Category</source>
        <translation>Nova categoria</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Localização</translation>
    </message>
    <message>
        <source>New name</source>
        <translation>Novo nome</translation>
    </message>
    <message>
        <source>Set location</source>
        <translation>Definir localização</translation>
    </message>
    <message>
        <source>Force reannounce</source>
        <translation>Forçar reinício</translation>
    </message>
    <message>
        <source>Edit Category</source>
        <translation>Editar categoria</translation>
    </message>
    <message>
        <source>Save path</source>
        <translation>Guardar em</translation>
    </message>
</context>
<context>
    <name>UpDownRatioDialog</name>
    <message>
        <source>Torrent Upload/Download Ratio Limiting</source>
        <translation>Limite de rácio para o upload/download dos torrents</translation>
    </message>
    <message>
        <source>Use global share limit</source>
        <translation>Utilizar limite de partilha global</translation>
    </message>
    <message>
        <source>Set no share limit</source>
        <translation>Definir ausência de limite de partilha</translation>
    </message>
    <message>
        <source>Set share limit to</source>
        <translation>Definir o limite de partilha para</translation>
    </message>
    <message>
        <source>ratio</source>
        <translation>rácio</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>minutos</translation>
    </message>
</context>
<context>
    <name>about</name>
    <message>
        <source>An advanced BitTorrent client programmed in C++, based on Qt toolkit and libtorrent-rasterbar.</source>
        <translation>Um cliente avançado de BitTorrent programado em C++, baseado em ferramentas QT e em 'libtorrent-rasterbar'.</translation>
    </message>
    <message>
        <source>Home Page:</source>
        <translation>Página inícial</translation>
    </message>
    <message>
        <source>Forum:</source>
        <translation>Fórum:</translation>
    </message>
    <message>
        <source>Bug Tracker:</source>
        <translation>Bug Tracker:</translation>
    </message>
</context>
<context>
    <name>confirmDeletionDlg</name>
    <message>
        <source>Deletion confirmation</source>
        <translation>Confirmação de eliminação</translation>
    </message>
    <message>
        <source>Also delete the files on the hard disk</source>
        <translation>Eliminar também os ficheiros existentes no disco rígido</translation>
    </message>
    <message>
        <source>Deletion confirmation - qBittorrent</source>
        <translation>Confirmação de eliminação - qBittorrent</translation>
    </message>
</context>
<context>
    <name>downloadFromURL</name>
    <message>
        <source>Download from URLs</source>
        <translation>Transferir a partir de URLs</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Download</translation>
    </message>
    <message>
        <source>Add Torrent Links</source>
        <translation>Adicionar ligações torrent</translation>
    </message>
</context>
<context>
    <name>misc</name>
    <message>
        <source>B</source>
        <comment>bytes</comment>
        <translation>B</translation>
    </message>
    <message>
        <source>KiB</source>
        <comment>kibibytes (1024 bytes)</comment>
        <translation>KB</translation>
    </message>
    <message>
        <source>MiB</source>
        <comment>mebibytes (1024 kibibytes)</comment>
        <translation>MB</translation>
    </message>
    <message>
        <source>GiB</source>
        <comment>gibibytes (1024 mibibytes)</comment>
        <translation>GB</translation>
    </message>
    <message>
        <source>TiB</source>
        <comment>tebibytes (1024 gibibytes)</comment>
        <translation>TB</translation>
    </message>
    <message>
        <source>PiB</source>
        <comment>pebibytes (1024 tebibytes)</comment>
        <translation>PiB</translation>
    </message>
    <message>
        <source>EiB</source>
        <comment>exbibytes (1024 pebibytes)</comment>
        <translation>EiB</translation>
    </message>
    <message>
        <source>/s</source>
        <comment>per second</comment>
        <translation>/s</translation>
    </message>
    <message>
        <source>%1h %2m</source>
        <comment>e.g: 3hours 5minutes</comment>
        <translation>%1 h e %2 m</translation>
    </message>
    <message>
        <source>%1d %2h</source>
        <comment>e.g: 2days 10hours</comment>
        <translation>%1 d e %2 h</translation>
    </message>
    <message>
        <source>Unknown</source>
        <comment>Unknown (size)</comment>
        <translation>Desconhecido</translation>
    </message>
    <message>
        <source>&lt; 1m</source>
        <comment>&lt; 1 minute</comment>
        <translation>&lt; 1 m</translation>
    </message>
    <message>
        <source>%1m</source>
        <comment>e.g: 10minutes</comment>
        <translation>%1 m</translation>
    </message>
</context>
<context>
    <name>TorrentsController</name>
    <message>
        <source>Save path is empty</source>
        <translation>O caminho de gravação encontra-se vazio</translation>
    </message>
</context>
<context>
    <name>PluginSourceDlg</name>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Plugin path:</source>
        <translation>Caminho do plugin:</translation>
    </message>
    <message>
        <source>URL or local directory</source>
        <translation>URL ou diretoria local</translation>
    </message>
    <message>
        <source>Install plugin</source>
        <translation>Instalar plugin</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
</context>
<context>
    <name>SearchEngineWidget</name>
    <message>
        <source>Seeds:</source>
        <translation>Sementes:</translation>
    </message>
    <message>
        <source>All plugins</source>
        <translation>Todos os plugins</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>Tamanho:</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Parar</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Procura</translation>
    </message>
    <message>
        <source>Search plugins...</source>
        <translation>Plugins de pesquisa...</translation>
    </message>
    <message>
        <source>All categories</source>
        <translation>Todas as categorias</translation>
    </message>
    <message>
        <source>Search in:</source>
        <translation>Pesquisar em:</translation>
    </message>
    <message>
        <source>Copy description page URL</source>
        <translation>Copiar URL da página de descrição</translation>
    </message>
    <message>
        <source>Go to description page</source>
        <translation>Ir para a página de descrição</translation>
    </message>
    <message>
        <source>Results (showing</source>
        <translation>Resultados (a mostrar</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Download</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>Filtro</translation>
    </message>
    <message>
        <source>Torrent names only</source>
        <translation>Apenas nomes de torrents</translation>
    </message>
    <message>
        <source>Only enabled</source>
        <translation>Apenas ativo</translation>
    </message>
    <message>
        <source>out of</source>
        <translation>fora de</translation>
    </message>
    <message>
        <source>Everywhere</source>
        <translation>Em tudo</translation>
    </message>
</context>
<context>
    <name>PluginSelectDlg</name>
    <message>
        <source>Uninstall</source>
        <translation>Desinstalar</translation>
    </message>
    <message>
        <source>Install new plugin</source>
        <translation>Instalar novo plugin</translation>
    </message>
    <message>
        <source>You can get new search engine plugins here:</source>
        <translation>Pode obter novos plugins do mecanismo de pesquisa aqui:</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Fechar</translation>
    </message>
    <message>
        <source>Installed search plugins:</source>
        <translation>Plugins de pesquisa instalados:</translation>
    </message>
    <message>
        <source>Enabled</source>
        <translation>Ativo</translation>
    </message>
    <message>
        <source>Warning: Be sure to comply with your country's copyright laws when downloading torrents from any of these search engines.</source>
        <translation>Aviso: Certifique-se que cumpre as leis de direitos de autor do seu país ao fazer o download de torrents a partir de qualquer um destes motores de busca.</translation>
    </message>
    <message>
        <source>Check for updates</source>
        <translation>Pesquisar por atualizações</translation>
    </message>
    <message>
        <source>Search plugins</source>
        <translation>Plugins de procura</translation>
    </message>
</context>
<context>
    <name>SearchResultsTable</name>
    <message>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Tamanho</translation>
    </message>
    <message>
        <source>Leechers</source>
        <translation>Sanguessugas</translation>
    </message>
    <message>
        <source>Search engine</source>
        <translation>Motor de pesquisa</translation>
    </message>
    <message>
        <source>Seeders</source>
        <translation>Semeadores</translation>
    </message>
</context>
<context>
    <name>SearchPluginsTable</name>
    <message>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <source>Url</source>
        <translation>Url</translation>
    </message>
    <message>
        <source>Enabled</source>
        <translation>Ativo</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Versão</translation>
    </message>
</context>
</TS>